import React, { useState } from "react";
import axios from "axios";
import styles from "./SearchUserForEditStyles.module.css";

/*
Page to search users by first and last name, and once 
the search results are found, users can click into a
edit user details page.
*/
const SearchUserForEdit = () => {
  // search params by first and last name
  const [searchParams, setSearchParams] = useState({
    firstName: "",
    lastName: "",
  });
  const [results, setResults] = useState([]);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setSearchParams((prev) => ({ ...prev, [name]: value }));
  };

  const handleSearch = async () => {
    setLoading(true);
    setError(null);

    try {
      const response = await axios.post(
        `${process.env.REACT_APP_API_URL}/person/searchByName`,
        {
          firstName: searchParams.firstName,
          lastName: searchParams.lastName,
        }
      );
      setResults(response.data.people); // set the list of people
    } catch (err) {
      setError(
        err.response?.data?.message || "An error occurred during the search."
      );
    } finally {
      setLoading(false);
    }
  };

  const handleDetailView = (personId) => {
    // Redirect to a detailed page for the selected person
    window.location.href = `/admin/edit-person/${personId}`;
  };

  return (
    <div className={styles.container}>
      <h2>Search for person to edit</h2>

      {/* Search Form */}
      <div className={styles.searchForm}>
        <label>
          First Name:
          <input
            type="text"
            name="firstName"
            value={searchParams.firstName}
            onChange={handleInputChange}
          />
        </label>
        <label>
          Last Name:
          <input
            type="text"
            name="lastName"
            value={searchParams.lastName}
            onChange={handleInputChange}
          />
        </label>
        <button onClick={handleSearch} disabled={loading}>
          {loading ? "Searching..." : "Search"}
        </button>
      </div>

      {/* Results Section */}
      {error && <p className={styles.error}>{error}</p>}
      {!error && results.length === 0 && !loading && <p>No results found.</p>}
      <ul className={styles.resultsList}>
        {results.map((person) => (
          <li
            key={person.id}
            className={styles.resultItem}
            onClick={() => handleDetailView(person.peopleId)}
          >
            Name: {person.firstName} {person.lastName} - Chapter:{" "}
            {person.techAlumniChapter} - Class year: {person.classYear}
          </li>
        ))}
      </ul>
    </div>
  );
};

export default SearchUserForEdit;
